rule win_helauto_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.helauto."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.helauto"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8b45d4 83c40c 898568ffffff 8b45d0 }
            // n = 4, score = 100
            //   8b45d4               | mov                 eax, dword ptr [ebp - 0x2c]
            //   83c40c               | add                 esp, 0xc
            //   898568ffffff         | mov                 dword ptr [ebp - 0x98], eax
            //   8b45d0               | mov                 eax, dword ptr [ebp - 0x30]

        $sequence_1 = { ff75ec ffd6 6830750000 eb48 }
            // n = 4, score = 100
            //   ff75ec               | push                dword ptr [ebp - 0x14]
            //   ffd6                 | call                esi
            //   6830750000           | push                0x7530
            //   eb48                 | jmp                 0x4a

        $sequence_2 = { 69c060ea0000 83c430 3d60ea0000 a3???????? }
            // n = 4, score = 100
            //   69c060ea0000         | imul                eax, eax, 0xea60
            //   83c430               | add                 esp, 0x30
            //   3d60ea0000           | cmp                 eax, 0xea60
            //   a3????????           |                     

        $sequence_3 = { 85c0 0f841f010000 8b3d???????? 6a05 8d85a8f3ffff 68???????? }
            // n = 6, score = 100
            //   85c0                 | test                eax, eax
            //   0f841f010000         | je                  0x125
            //   8b3d????????         |                     
            //   6a05                 | push                5
            //   8d85a8f3ffff         | lea                 eax, [ebp - 0xc58]
            //   68????????           |                     

        $sequence_4 = { 59 50 8d8574ffffff 50 53 53 ff75fc }
            // n = 7, score = 100
            //   59                   | pop                 ecx
            //   50                   | push                eax
            //   8d8574ffffff         | lea                 eax, [ebp - 0x8c]
            //   50                   | push                eax
            //   53                   | push                ebx
            //   53                   | push                ebx
            //   ff75fc               | push                dword ptr [ebp - 4]

        $sequence_5 = { 85c0 7508 53 ff15???????? 59 33c0 }
            // n = 6, score = 100
            //   85c0                 | test                eax, eax
            //   7508                 | jne                 0xa
            //   53                   | push                ebx
            //   ff15????????         |                     
            //   59                   | pop                 ecx
            //   33c0                 | xor                 eax, eax

        $sequence_6 = { 50 ff15???????? 83c40c 85c0 0f8593000000 50 }
            // n = 6, score = 100
            //   50                   | push                eax
            //   ff15????????         |                     
            //   83c40c               | add                 esp, 0xc
            //   85c0                 | test                eax, eax
            //   0f8593000000         | jne                 0x99
            //   50                   | push                eax

        $sequence_7 = { 68???????? 50 ff15???????? 83c40c 85c0 0f8593000000 }
            // n = 6, score = 100
            //   68????????           |                     
            //   50                   | push                eax
            //   ff15????????         |                     
            //   83c40c               | add                 esp, 0xc
            //   85c0                 | test                eax, eax
            //   0f8593000000         | jne                 0x99

        $sequence_8 = { 8d4608 50 68???????? 53 e8???????? 83c418 83feff }
            // n = 7, score = 100
            //   8d4608               | lea                 eax, [esi + 8]
            //   50                   | push                eax
            //   68????????           |                     
            //   53                   | push                ebx
            //   e8????????           |                     
            //   83c418               | add                 esp, 0x18
            //   83feff               | cmp                 esi, -1

        $sequence_9 = { 51 8d4df0 e8???????? 8365fc00 8d4df0 }
            // n = 5, score = 100
            //   51                   | push                ecx
            //   8d4df0               | lea                 ecx, [ebp - 0x10]
            //   e8????????           |                     
            //   8365fc00             | and                 dword ptr [ebp - 4], 0
            //   8d4df0               | lea                 ecx, [ebp - 0x10]

    condition:
        7 of them and filesize < 57344
}